==> apache-camel-4.7.0-src.zip: apache-camel-4.7.0/components/camel-ai/camel-djl/src/main/java/org/apache/camel/component/djl/model/cv/ZooActionRecognitionPredictor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.djl.model.cv;

import java.io.IOException;

import ai.djl.Application;
import ai.djl.MalformedModelException;
import ai.djl.modality.Classifications;
import ai.djl.modality.cv.Image;
import ai.djl.repository.zoo.Criteria;
import ai.djl.repository.zoo.ModelNotFoundException;
import ai.djl.repository.zoo.ModelZoo;
import ai.djl.training.util.ProgressBar;

public class ZooActionRecognitionPredictor extends AbstractCvZooPredictor<Classifications> {
    public ZooActionRecognitionPredictor(String artifactId) throws ModelNotFoundException, MalformedModelException,
                                                            IOException {
        Criteria<Image, Classifications> criteria = Criteria.builder()
                .optApplication(Application.CV.ACTION_RECOGNITION)
                .setTypes(Image.class, Classifications.class)
                .optArtifactId(artifactId)
                .optProgress(new ProgressBar())
                .build();
        this.model = ModelZoo.loadModel(criteria);
    }
}

==> apache-camel-4.10.7-src.zip: apache-camel-4.10.7/components/camel-ai/camel-djl/src/main/java/org/apache/camel/component/djl/model/cv/ZooActionRecognitionPredictor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.djl.model.cv;

import java.io.IOException;

import ai.djl.Application;
import ai.djl.MalformedModelException;
import ai.djl.modality.Classifications;
import ai.djl.modality.cv.Image;
import ai.djl.repository.zoo.Criteria;
import ai.djl.repository.zoo.ModelNotFoundException;
import ai.djl.repository.zoo.ModelZoo;
import ai.djl.training.util.ProgressBar;
import org.apache.camel.component.djl.DJLEndpoint;

public class ZooActionRecognitionPredictor extends AbstractCvZooPredictor<Classifications> {
    public ZooActionRecognitionPredictor(DJLEndpoint endpoint) throws ModelNotFoundException, MalformedModelException,
                                                               IOException {
        super(endpoint);

        Criteria.Builder<Image, Classifications> builder = Criteria.builder()
                .optApplication(Application.CV.ACTION_RECOGNITION)
                .setTypes(Image.class, Classifications.class)
                .optArtifactId(endpoint.getArtifactId());
        if (endpoint.isShowProgress()) {
            builder.optProgress(new ProgressBar());
        }

        Criteria<Image, Classifications> criteria = builder.build();
        this.model = ModelZoo.loadModel(criteria);
    }
}
